@@ -1,9 +1,9 @@
 package Sort::Sub::pod_section_ala_perlancar;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-23'; # DATE
+our $DATE = '2021-05-01'; # DATE
 our $DIST = 'Sort-SubBundle-PERLANCAR'; # DIST
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.087'; # VERSION
 
 use 5.010001;
 use strict;
@@ -69,7 +69,6 @@ our $SORT_SPEC = [
     'HOMEPAGE', 'ORIGINAL HOMEPAGE',
     'SOURCE', 'ORIGINAL SOURCE',
     'BUGS', 'ORIGINAL BUGS',
-    qr/^.+'S BUGS$/i, # in a forked module, i put the original module's BUGS in ORIGMODULE'S BUGS
     'GOTCHAS',
     'CAVEATS',
     'SEE ALSO', 'ORIGINAL SEE ALSO',
@@ -80,12 +79,11 @@ our $SORT_SPEC = [
 
     # author & copyright
     qr/^AUTHORS?/,
-    qr/^.+'S AUTHORS?$/i, # in a forked module, i put the original module's AUTHOR in ORIGMODULE'S AUTHOR
     qr/^ORIGINAL AUTHORS?/,
 
     'COPYRIGHT AND LICENSE', 'ORIGINAL COPYRIGHT AND LICENSE',
     'COPYRIGHT', 'ORIGINAL COPYRIGHT',
-    qr/^.+'S COPYRIGHT( AND LICENSE)?$/i, # in a forked module, i put the original module's COPYRIGHT in ORIGMODULE'S COPYRIGHT
+    'LICENSE', 'ORIGINAL LICENSE',
 ];
 
 sub meta {
@@ -121,7 +119,7 @@ Sort::Sub::pod_section_ala_perlancar - Sort POD sections (headings) PERLANCAR-st
 
 =head1 VERSION
 
-This document describes version 0.086 of Sort::Sub::pod_section_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-04-23.
+This document describes version 0.087 of Sort::Sub::pod_section_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-05-01.
 
 =head1 SYNOPSIS
 
@@ -174,7 +172,7 @@ Source repository is at L<https://github.com/perlancar/perl-Sort-SubBundle-PERLA
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Sort-SubBundle-PERLANCAR/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-SubBundle-PERLANCAR>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -194,7 +192,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
