@@ -1,9 +1,9 @@
 package Sort::SubBundle::PERLANCAR;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-23'; # DATE
+our $DATE = '2021-05-01'; # DATE
 our $DIST = 'Sort-SubBundle-PERLANCAR'; # DIST
-our $VERSION = '0.086'; # VERSION
+our $VERSION = '0.087'; # VERSION
 
 1;
 # ABSTRACT: PERLANCAR's Sort::Sub subroutines
@@ -20,7 +20,7 @@ Sort::SubBundle::PERLANCAR - PERLANCAR's Sort::Sub subroutines
 
 =head1 VERSION
 
-This document describes version 0.086 of Sort::SubBundle::PERLANCAR (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-04-23.
+This document describes version 0.087 of Sort::SubBundle::PERLANCAR (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-05-01.
 
 =head1 HOMEPAGE
 
@@ -32,7 +32,7 @@ Source repository is at L<https://github.com/perlancar/perl-Sort-SubBundle-PERLA
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Sort-SubBundle-PERLANCAR/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-SubBundle-PERLANCAR>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -44,7 +44,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
